complete -c zellij -n "__fish_use_subcommand" -l max-panes -d 'Maximum panes on screen, caution: opening more panes will close old ones' -r
complete -c zellij -n "__fish_use_subcommand" -l data-dir -d 'Change where zellij looks for plugins' -r -F
complete -c zellij -n "__fish_use_subcommand" -l server -d 'Run server listening at the specified socket path' -r -F
complete -c zellij -n "__fish_use_subcommand" -s s -l session -d 'Specify name of a new session' -r
complete -c zellij -n "__fish_use_subcommand" -s l -l layout -d 'Name of a predefined layout inside the layout directory or the path to a layout file' -r -F
complete -c zellij -n "__fish_use_subcommand" -s c -l config -d 'Change where zellij looks for the configuration file' -r -F
complete -c zellij -n "__fish_use_subcommand" -l config-dir -d 'Change where zellij looks for the configuration directory' -r -F
complete -c zellij -n "__fish_use_subcommand" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_use_subcommand" -s V -l version -d 'Print version information'
complete -c zellij -n "__fish_use_subcommand" -s d -l debug -d 'Specify emitting additional debug information'
complete -c zellij -n "__fish_use_subcommand" -f -a "options" -d 'Change the behaviour of zellij'
complete -c zellij -n "__fish_use_subcommand" -f -a "setup" -d 'Setup zellij and check its configuration'
complete -c zellij -n "__fish_use_subcommand" -f -a "list-sessions" -d 'List active sessions'
complete -c zellij -n "__fish_use_subcommand" -f -a "attach" -d 'Attach to a session'
complete -c zellij -n "__fish_use_subcommand" -f -a "kill-session" -d 'Kill a specific session'
complete -c zellij -n "__fish_use_subcommand" -f -a "delete-session" -d 'Delete a specific session'
complete -c zellij -n "__fish_use_subcommand" -f -a "kill-all-sessions" -d 'Kill all sessions'
complete -c zellij -n "__fish_use_subcommand" -f -a "delete-all-sessions" -d 'Delete all sessions'
complete -c zellij -n "__fish_use_subcommand" -f -a "action" -d 'Send actions to a specific session'
complete -c zellij -n "__fish_use_subcommand" -f -a "run" -d 'Run a command in a new pane'
complete -c zellij -n "__fish_use_subcommand" -f -a "plugin" -d 'Load a plugin'
complete -c zellij -n "__fish_use_subcommand" -f -a "edit" -d 'Edit file with default $EDITOR / $VISUAL'
complete -c zellij -n "__fish_use_subcommand" -f -a "convert-config"
complete -c zellij -n "__fish_use_subcommand" -f -a "convert-layout"
complete -c zellij -n "__fish_use_subcommand" -f -a "convert-theme"
complete -c zellij -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c zellij -n "__fish_seen_subcommand_from options" -l simplified-ui -d 'Allow plugins to use a more simplified layout that is compatible with more fonts (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l theme -d 'Set the default theme' -r
complete -c zellij -n "__fish_seen_subcommand_from options" -l default-mode -d 'Set the default mode' -r -f -a "{normal	In `Normal` mode, input is always written to the terminal, except for the shortcuts leading to other modes,locked	In `Locked` mode, input is always written to the terminal and all shortcuts are disabled except the one leading back to normal mode,resize	`Resize` mode allows resizing the different existing panes,pane	`Pane` mode allows creating and closing panes, as well as moving between them,tab	`Tab` mode allows creating and closing tabs, as well as moving between them,scroll	`Scroll` mode allows scrolling up and down within a pane,enter-search	`EnterSearch` mode allows for typing in the needle for a search in the scroll buffer of a pane,search	`Search` mode allows for searching a term in a pane (superset of `Scroll`),rename-tab	`RenameTab` mode allows assigning a new name to a tab,rename-pane	`RenamePane` mode allows assigning a new name to a pane,session	`Session` mode allows detaching sessions,move	`Move` mode allows moving the different existing panes within a tab,prompt	`Prompt` mode allows interacting with active prompts,tmux	`Tmux` mode allows for basic tmux keybindings functionality}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l default-shell -d 'Set the default shell' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l default-cwd -d 'Set the default cwd' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l default-layout -d 'Set the default layout' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l layout-dir -d 'Set the layout_dir, defaults to subdirectory of config dir' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l theme-dir -d 'Set the theme_dir, defaults to subdirectory of config dir' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l mouse-mode -d 'Set the handling of mouse events (true or false) Can be temporarily bypassed by the [SHIFT] key' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l pane-frames -d 'Set display of the pane frames (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l mirror-session -d 'Mirror session when multiple users are connected (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l on-force-close -d 'Set behaviour on force close (quit or detach)' -r -f -a "{quit	,detach	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l scroll-buffer-size -r
complete -c zellij -n "__fish_seen_subcommand_from options" -l copy-command -d 'Switch to using a user supplied command for clipboard instead of OSC52' -r
complete -c zellij -n "__fish_seen_subcommand_from options" -l copy-clipboard -d 'OSC52 destination clipboard' -r -f -a "{system	,primary	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l copy-on-select -d 'Automatically copy when selecting text (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l scrollback-editor -d 'Explicit full path to open the scrollback editor (default is $EDITOR or $VISUAL)' -r -F
complete -c zellij -n "__fish_seen_subcommand_from options" -l session-name -d 'The name of the session to create when starting Zellij' -r
complete -c zellij -n "__fish_seen_subcommand_from options" -l attach-to-session -d 'Whether to attach to a session specified in "session-name" if it exists' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l auto-layout -d 'Whether to lay out panes in a predefined set of layouts whenever possible' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l session-serialization -d 'Whether sessions should be serialized to the HD so that they can be later resurrected, default is true' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l serialize-pane-viewport -d 'Whether pane viewports are serialized along with the session, default is false' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l scrollback-lines-to-serialize -d 'Scrollback lines to serialize along with the pane viewport when serializing sessions, 0 defaults to the scrollback size. If this number is higher than the scrollback size, it will also default to the scrollback size' -r
complete -c zellij -n "__fish_seen_subcommand_from options" -l styled-underlines -d 'Whether to use ANSI styled underlines' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from options" -l disable-mouse-mode -d 'Disable handling of mouse events'
complete -c zellij -n "__fish_seen_subcommand_from options" -l no-pane-frames -d 'Disable display of pane frames'
complete -c zellij -n "__fish_seen_subcommand_from options" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from setup" -l dump-layout -d 'Dump specified layout to stdout' -r
complete -c zellij -n "__fish_seen_subcommand_from setup" -l dump-swap-layout -d 'Dump the specified swap layout file to stdout' -r
complete -c zellij -n "__fish_seen_subcommand_from setup" -l dump-plugins -d 'Dump the builtin plugins to DIR or "DATA DIR" if unspecified' -r -F
complete -c zellij -n "__fish_seen_subcommand_from setup" -l generate-completion -d 'Generates completion for the specified shell' -r
complete -c zellij -n "__fish_seen_subcommand_from setup" -l generate-auto-start -d 'Generates auto-start script for the specified shell' -r
complete -c zellij -n "__fish_seen_subcommand_from setup" -l dump-config -d 'Dump the default configuration file to stdout'
complete -c zellij -n "__fish_seen_subcommand_from setup" -l clean -d 'Disables loading of configuration file at default location, loads the defaults that zellij ships with'
complete -c zellij -n "__fish_seen_subcommand_from setup" -l check -d 'Checks the configuration of zellij and displays currently used directories'
complete -c zellij -n "__fish_seen_subcommand_from setup" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from list-sessions" -s n -l no-formatting -d 'Do not add colors and formatting to the list (useful for parsing)'
complete -c zellij -n "__fish_seen_subcommand_from list-sessions" -s s -l short -d 'Print just the session name'
complete -c zellij -n "__fish_seen_subcommand_from list-sessions" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -l index -d 'Number of the session index in the active sessions ordered creation date' -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -s c -l create -d 'Create a session if one does not exist'
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -s f -l force-run-commands -d 'If resurrecting a dead session, immediately run all its commands on startup'
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -f -a "options" -d 'Change the behaviour of zellij'
complete -c zellij -n "__fish_seen_subcommand_from attach; and not __fish_seen_subcommand_from options; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l simplified-ui -d 'Allow plugins to use a more simplified layout that is compatible with more fonts (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l theme -d 'Set the default theme' -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l default-mode -d 'Set the default mode' -r -f -a "{normal	In `Normal` mode, input is always written to the terminal, except for the shortcuts leading to other modes,locked	In `Locked` mode, input is always written to the terminal and all shortcuts are disabled except the one leading back to normal mode,resize	`Resize` mode allows resizing the different existing panes,pane	`Pane` mode allows creating and closing panes, as well as moving between them,tab	`Tab` mode allows creating and closing tabs, as well as moving between them,scroll	`Scroll` mode allows scrolling up and down within a pane,enter-search	`EnterSearch` mode allows for typing in the needle for a search in the scroll buffer of a pane,search	`Search` mode allows for searching a term in a pane (superset of `Scroll`),rename-tab	`RenameTab` mode allows assigning a new name to a tab,rename-pane	`RenamePane` mode allows assigning a new name to a pane,session	`Session` mode allows detaching sessions,move	`Move` mode allows moving the different existing panes within a tab,prompt	`Prompt` mode allows interacting with active prompts,tmux	`Tmux` mode allows for basic tmux keybindings functionality}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l default-shell -d 'Set the default shell' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l default-cwd -d 'Set the default cwd' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l default-layout -d 'Set the default layout' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l layout-dir -d 'Set the layout_dir, defaults to subdirectory of config dir' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l theme-dir -d 'Set the theme_dir, defaults to subdirectory of config dir' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l mouse-mode -d 'Set the handling of mouse events (true or false) Can be temporarily bypassed by the [SHIFT] key' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l pane-frames -d 'Set display of the pane frames (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l mirror-session -d 'Mirror session when multiple users are connected (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l on-force-close -d 'Set behaviour on force close (quit or detach)' -r -f -a "{quit	,detach	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l scroll-buffer-size -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l copy-command -d 'Switch to using a user supplied command for clipboard instead of OSC52' -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l copy-clipboard -d 'OSC52 destination clipboard' -r -f -a "{system	,primary	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l copy-on-select -d 'Automatically copy when selecting text (true or false)' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l scrollback-editor -d 'Explicit full path to open the scrollback editor (default is $EDITOR or $VISUAL)' -r -F
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l session-name -d 'The name of the session to create when starting Zellij' -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l attach-to-session -d 'Whether to attach to a session specified in "session-name" if it exists' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l auto-layout -d 'Whether to lay out panes in a predefined set of layouts whenever possible' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l session-serialization -d 'Whether sessions should be serialized to the HD so that they can be later resurrected, default is true' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l serialize-pane-viewport -d 'Whether pane viewports are serialized along with the session, default is false' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l scrollback-lines-to-serialize -d 'Scrollback lines to serialize along with the pane viewport when serializing sessions, 0 defaults to the scrollback size. If this number is higher than the scrollback size, it will also default to the scrollback size' -r
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l styled-underlines -d 'Whether to use ANSI styled underlines' -r -f -a "{true	,false	}"
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l disable-mouse-mode -d 'Disable handling of mouse events'
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -l no-pane-frames -d 'Disable display of pane frames'
complete -c zellij -n "__fish_seen_subcommand_from attach; and __fish_seen_subcommand_from options" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from kill-session" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from delete-session" -s f -l force -d 'Kill the session if it\'s running before deleting it'
complete -c zellij -n "__fish_seen_subcommand_from delete-session" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from kill-all-sessions" -s y -l yes -d 'Automatic yes to prompts'
complete -c zellij -n "__fish_seen_subcommand_from kill-all-sessions" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from delete-all-sessions" -s y -l yes -d 'Automatic yes to prompts'
complete -c zellij -n "__fish_seen_subcommand_from delete-all-sessions" -s f -l force -d 'Kill the sessions if they\'re running before deleting them'
complete -c zellij -n "__fish_seen_subcommand_from delete-all-sessions" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "write" -d 'Write bytes to the terminal'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "write-chars" -d 'Write characters to the terminal'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "resize" -d '[increase|decrease] the focused panes area at the [left|down|up|right] border'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "focus-next-pane" -d 'Change focus to the next pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "focus-previous-pane" -d 'Change focus to the previous pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "move-focus" -d 'Move the focused pane in the specified direction. [right|left|up|down]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "move-focus-or-tab" -d 'Move focus to the pane or tab (if on screen edge) in the specified direction [right|left|up|down]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "move-pane" -d 'Change the location of the focused pane in the specified direction or rotate forwrads [right|left|up|down]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "move-pane-backwards" -d 'Rotate the location of the previous pane backwards'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "clear" -d 'Clear all buffers for a focused pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "dump-screen" -d 'Dump the focused pane to a file'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "dump-layout" -d 'Dump current layout to stdout'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "edit-scrollback" -d 'Open the pane scrollback in your default editor'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "scroll-up" -d 'Scroll up in the focused pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "scroll-down" -d 'Scroll down in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "scroll-to-bottom" -d 'Scroll down to bottom in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "scroll-to-top" -d 'Scroll up to top in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "page-scroll-up" -d 'Scroll up one page in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "page-scroll-down" -d 'Scroll down one page in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "half-page-scroll-up" -d 'Scroll up half page in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "half-page-scroll-down" -d 'Scroll down half page in focus pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "toggle-fullscreen" -d 'Toggle between fullscreen focus pane and normal layout'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "toggle-pane-frames" -d 'Toggle frames around panes in the UI'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "toggle-active-sync-tab" -d 'Toggle between sending text commands to all panes on the current tab and normal mode'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "new-pane" -d 'Open a new pane in the specified direction [right|down] If no direction is specified, will try to use the biggest available space'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Open the specified file in a new zellij pane with your default EDITOR'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "switch-mode" -d 'Switch input mode of all connected clients [locked|pane|tab|resize|move|search|session]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "toggle-pane-embed-or-floating" -d 'Embed focused pane if floating or float focused pane if embedded'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "toggle-floating-panes" -d 'Toggle the visibility of all fdirectionloating panes in the current Tab, open one if none exist'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "close-pane" -d 'Close the focused pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "rename-pane" -d 'Renames the focused pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "undo-rename-pane" -d 'Remove a previously set pane name'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "go-to-next-tab" -d 'Go to the next tab'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "go-to-previous-tab" -d 'Go to the previous tab'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "close-tab" -d 'Close the current tab'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "go-to-tab" -d 'Go to tab with index [index]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "go-to-tab-name" -d 'Go to tab with name [name]'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "rename-tab" -d 'Renames the focused pane'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "undo-rename-tab" -d 'Remove a previously set tab name'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "new-tab" -d 'Create a new tab, optionally with a specified tab layout and name'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "previous-swap-layout"
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "next-swap-layout"
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "query-tab-names" -d 'Query all tab names'
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "start-or-reload-plugin"
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "launch-or-focus-plugin"
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "rename-session"
complete -c zellij -n "__fish_seen_subcommand_from action; and not __fish_seen_subcommand_from write; and not __fish_seen_subcommand_from write-chars; and not __fish_seen_subcommand_from resize; and not __fish_seen_subcommand_from focus-next-pane; and not __fish_seen_subcommand_from focus-previous-pane; and not __fish_seen_subcommand_from move-focus; and not __fish_seen_subcommand_from move-focus-or-tab; and not __fish_seen_subcommand_from move-pane; and not __fish_seen_subcommand_from move-pane-backwards; and not __fish_seen_subcommand_from clear; and not __fish_seen_subcommand_from dump-screen; and not __fish_seen_subcommand_from dump-layout; and not __fish_seen_subcommand_from edit-scrollback; and not __fish_seen_subcommand_from scroll-up; and not __fish_seen_subcommand_from scroll-down; and not __fish_seen_subcommand_from scroll-to-bottom; and not __fish_seen_subcommand_from scroll-to-top; and not __fish_seen_subcommand_from page-scroll-up; and not __fish_seen_subcommand_from page-scroll-down; and not __fish_seen_subcommand_from half-page-scroll-up; and not __fish_seen_subcommand_from half-page-scroll-down; and not __fish_seen_subcommand_from toggle-fullscreen; and not __fish_seen_subcommand_from toggle-pane-frames; and not __fish_seen_subcommand_from toggle-active-sync-tab; and not __fish_seen_subcommand_from new-pane; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from switch-mode; and not __fish_seen_subcommand_from toggle-pane-embed-or-floating; and not __fish_seen_subcommand_from toggle-floating-panes; and not __fish_seen_subcommand_from close-pane; and not __fish_seen_subcommand_from rename-pane; and not __fish_seen_subcommand_from undo-rename-pane; and not __fish_seen_subcommand_from go-to-next-tab; and not __fish_seen_subcommand_from go-to-previous-tab; and not __fish_seen_subcommand_from close-tab; and not __fish_seen_subcommand_from go-to-tab; and not __fish_seen_subcommand_from go-to-tab-name; and not __fish_seen_subcommand_from rename-tab; and not __fish_seen_subcommand_from undo-rename-tab; and not __fish_seen_subcommand_from new-tab; and not __fish_seen_subcommand_from previous-swap-layout; and not __fish_seen_subcommand_from next-swap-layout; and not __fish_seen_subcommand_from query-tab-names; and not __fish_seen_subcommand_from start-or-reload-plugin; and not __fish_seen_subcommand_from launch-or-focus-plugin; and not __fish_seen_subcommand_from rename-session; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from write" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from write-chars" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from resize" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from focus-next-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from focus-previous-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from move-focus" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from move-focus-or-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from move-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from move-pane-backwards" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from dump-screen" -s f -l full -d 'Dump the pane with full scrollback'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from dump-screen" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from dump-layout" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit-scrollback" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from scroll-up" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from scroll-down" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from scroll-to-bottom" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from scroll-to-top" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from page-scroll-up" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from page-scroll-down" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from half-page-scroll-up" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from half-page-scroll-down" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from toggle-fullscreen" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from toggle-pane-frames" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from toggle-active-sync-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s d -l direction -d 'Direction to open the new pane in' -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s p -l plugin -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -l cwd -d 'Change the working directory of the new pane' -r -F
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s n -l name -d 'Name of the new pane' -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -l configuration -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s f -l floating -d 'Open the new pane in floating mode'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s i -l in-place -d 'Open the new pane in place of the current pane, temporarily suspending it'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s c -l close-on-exit -d 'Close the pane immediately when its command exits'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s s -l start-suspended -d 'Start the command suspended, only running it after the you first press ENTER'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -s d -l direction -d 'Direction to open the new pane in' -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -s l -l line-number -d 'Open the file in the specified line number' -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -l cwd -d 'Change the working directory of the editor' -r -F
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -s f -l floating -d 'Open the new pane in floating mode'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -s i -l in-place -d 'Open the new pane in place of the current pane, temporarily suspending it'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from switch-mode" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from toggle-pane-embed-or-floating" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from toggle-floating-panes" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from close-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from rename-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from undo-rename-pane" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from go-to-next-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from go-to-previous-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from close-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from go-to-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from go-to-tab-name" -s c -l create -d 'Create a tab if one does not exist'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from go-to-tab-name" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from rename-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from undo-rename-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-tab" -s l -l layout -d 'Layout to use for the new tab' -r -F
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-tab" -l layout-dir -d 'Default folder to look for layouts' -r -F
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-tab" -s n -l name -d 'Name of the new tab' -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-tab" -s c -l cwd -d 'Change the working directory of the new tab' -r -F
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from new-tab" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from previous-swap-layout" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from next-swap-layout" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from query-tab-names" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from start-or-reload-plugin" -s c -l configuration -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from start-or-reload-plugin" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from launch-or-focus-plugin" -s c -l configuration -r
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from launch-or-focus-plugin" -s f -l floating
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from launch-or-focus-plugin" -s i -l in-place
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from launch-or-focus-plugin" -s m -l move-to-focused-tab
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from launch-or-focus-plugin" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from action; and __fish_seen_subcommand_from rename-session" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from run" -s d -l direction -d 'Direction to open the new pane in' -r
complete -c zellij -n "__fish_seen_subcommand_from run" -l cwd -d 'Change the working directory of the new pane' -r -F
complete -c zellij -n "__fish_seen_subcommand_from run" -s n -l name -d 'Name of the new pane' -r
complete -c zellij -n "__fish_seen_subcommand_from run" -s f -l floating -d 'Open the new pane in floating mode'
complete -c zellij -n "__fish_seen_subcommand_from run" -s i -l in-place -d 'Open the new pane in place of the current pane, temporarily suspending it'
complete -c zellij -n "__fish_seen_subcommand_from run" -s c -l close-on-exit -d 'Close the pane immediately when its command exits'
complete -c zellij -n "__fish_seen_subcommand_from run" -s s -l start-suspended -d 'Start the command suspended, only running after you first presses ENTER'
complete -c zellij -n "__fish_seen_subcommand_from run" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from plugin" -s c -l configuration -d 'Plugin configuration' -r
complete -c zellij -n "__fish_seen_subcommand_from plugin" -s f -l floating -d 'Open the new pane in floating mode'
complete -c zellij -n "__fish_seen_subcommand_from plugin" -s i -l in-place -d 'Open the new pane in place of the current pane, temporarily suspending it'
complete -c zellij -n "__fish_seen_subcommand_from plugin" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from edit" -s l -l line-number -d 'Open the file in the specified line number' -r
complete -c zellij -n "__fish_seen_subcommand_from edit" -s d -l direction -d 'Direction to open the new pane in' -r
complete -c zellij -n "__fish_seen_subcommand_from edit" -l cwd -d 'Change the working directory of the editor' -r -F
complete -c zellij -n "__fish_seen_subcommand_from edit" -s i -l in-place -d 'Open the new pane in place of the current pane, temporarily suspending it'
complete -c zellij -n "__fish_seen_subcommand_from edit" -s f -l floating -d 'Open the new pane in floating mode'
complete -c zellij -n "__fish_seen_subcommand_from edit" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from convert-config" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from convert-layout" -s h -l help -d 'Print help information'
complete -c zellij -n "__fish_seen_subcommand_from convert-theme" -s h -l help -d 'Print help information'
function __fish_complete_sessions
    zellij list-sessions --short --no-formatting 2>/dev/null
end
complete -c zellij -n "__fish_seen_subcommand_from attach" -f -a "(__fish_complete_sessions)" -d "Session"
complete -c zellij -n "__fish_seen_subcommand_from a" -f -a "(__fish_complete_sessions)" -d "Session"
complete -c zellij -n "__fish_seen_subcommand_from kill-session" -f -a "(__fish_complete_sessions)" -d "Session"
complete -c zellij -n "__fish_seen_subcommand_from k" -f -a "(__fish_complete_sessions)" -d "Session"
complete -c zellij -n "__fish_seen_subcommand_from setup" -l "generate-completion" -x -a "bash elvish fish zsh powershell" -d "Shell"
function zr
  command zellij run --name "$argv" -- fish -c "$argv"
end
function zrf
  command zellij run --name "$argv" --floating -- fish -c "$argv"
end
function ze
  command zellij edit $argv
end
function zef
  command zellij edit --floating $argv
end
